@@ -37,7 +37,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.9.7"
+#define LIBGNUTLS_VERSION "0.9.90"
 
 /* For backwards compatibility */
 #include <gnutls/compat4.h>
@@ -45,14 +45,14 @@ extern "C" {
 #include <sys/types.h>
 #include <time.h>
 
-#define GNUTLS_CIPHER_AES_128_CBC GNUTLS_CIPHER_RIJNDAEL_128_CBC
-#define GNUTLS_CIPHER_AES_256_CBC GNUTLS_CIPHER_RIJNDAEL_256_CBC
-#define GNUTLS_CIPHER_RIJNDAEL_CBC GNUTLS_CIPHER_RIJNDAEL_128_CBC
+#define GNUTLS_CIPHER_RIJNDAEL_128_CBC GNUTLS_CIPHER_AES_128_CBC
+#define GNUTLS_CIPHER_RIJNDAEL_256_CBC GNUTLS_CIPHER_AES_256_CBC
+#define GNUTLS_CIPHER_RIJNDAEL_CBC GNUTLS_CIPHER_AES_128_CBC
 #define GNUTLS_CIPHER_ARCFOUR GNUTLS_CIPHER_ARCFOUR_128
 
 typedef enum gnutls_cipher_algorithm { GNUTLS_CIPHER_NULL=1, 
-	GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_RIJNDAEL_128_CBC, 
-	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_RIJNDAEL_256_CBC,
+	GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_AES_128_CBC, 
+	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_AES_256_CBC,
 	GNUTLS_CIPHER_ARCFOUR_40
 } gnutls_cipher_algorithm;
 
@@ -392,11 +392,11 @@ int gnutls_dh_params_import_raw(gnutls_dh_params dh_params, const gnutls_datum *
 			const gnutls_datum* generator);
 int gnutls_dh_params_import_pkcs3(gnutls_dh_params params, 
 	const gnutls_datum * pkcs3_params, gnutls_x509_crt_fmt format);
-int gnutls_dh_params_generate2(gnutls_dh_params params, int bits);
+int gnutls_dh_params_generate2(gnutls_dh_params params, unsigned int bits);
 int gnutls_dh_params_export_pkcs3( gnutls_dh_params params,
 	   gnutls_x509_crt_fmt format, unsigned char* params_data, int* params_data_size);
 int gnutls_dh_params_export_raw(gnutls_dh_params params,
-	gnutls_datum * prime, gnutls_datum * generator, int *bits);
+	gnutls_datum * prime, gnutls_datum * generator, unsigned int *bits);
 
 
 /* RSA params 
@@ -407,11 +407,11 @@ int gnutls_rsa_params_import_raw(gnutls_rsa_params rsa_params,
 	const gnutls_datum *m, const gnutls_datum *e,
 	const gnutls_datum *d, const gnutls_datum *p, 
 	const gnutls_datum *q, const gnutls_datum *u);
-int gnutls_rsa_params_generate2(gnutls_rsa_params params, int bits);
+int gnutls_rsa_params_generate2(gnutls_rsa_params params, unsigned int bits);
 int gnutls_rsa_params_export_raw(gnutls_rsa_params params,
 	gnutls_datum * m, gnutls_datum *e,
 	gnutls_datum *d, gnutls_datum *p, gnutls_datum* q, 
-	gnutls_datum* u, int *bits);
+	gnutls_datum* u, unsigned int *bits);
 
 /* Session stuff
  */
@@ -471,7 +471,7 @@ gnutls_credentials_type gnutls_auth_get_type( gnutls_session session);
 
 /* DH */
 
-void gnutls_dh_set_prime_bits( gnutls_session session, int bits);
+void gnutls_dh_set_prime_bits( gnutls_session session, unsigned int bits);
 int gnutls_dh_get_prime_bits( gnutls_session);
 int gnutls_dh_get_secret_bits( gnutls_session);
 int gnutls_dh_get_peers_public_bits( gnutls_session);
@@ -493,7 +493,7 @@ void gnutls_certificate_server_set_request( gnutls_session, gnutls_certificate_r
 
 int gnutls_pkcs3_extract_dh_params(const gnutls_datum * params,
 	gnutls_x509_crt_fmt format, gnutls_datum * prime,
-	gnutls_datum * generator, int* prime_bits);
+	gnutls_datum * generator, unsigned int* prime_bits);
 int gnutls_pkcs3_export_dh_params( const gnutls_datum * prime,
 	const gnutls_datum * generator, gnutls_x509_crt_fmt format,
 	unsigned char* params_data, int* params_data_size);
