@@ -8,7 +8,7 @@ typedef struct gnutls_x509_crq_int {
 typedef struct gnutls_x509_crq_int *gnutls_x509_crq;
 
 int gnutls_x509_crt_get_dn_by_oid(gnutls_x509_crt cert, const char* oid, 
-	int indx, char *buf, int *sizeof_buf);
+	int indx, char *buf, size_t *sizeof_buf);
 
 int gnutls_x509_crq_init(gnutls_x509_crq * crq);
 void gnutls_x509_crq_deinit(gnutls_x509_crq crq);
